@@ -130,7 +130,6 @@ def instrument_handlers_base(module):
             return callback
         
         return trace
-
     if hasattr(module.BaseHandler, 'apply_response_fixes'):
         module.BaseHandler.apply_response_fixes = wrapper(
             module.BaseHandler.apply_response_fixes)
@@ -152,7 +151,6 @@ def instrument_handlers_base(module):
             return callback
         
         return trace
-
     if hasattr(module.BaseHandler, 'handle_uncaught_exception'):
         module.BaseHandler.handle_uncaught_exception = wrapper(
             module.BaseHandler.handle_uncaught_exception)
@@ -183,6 +181,24 @@ def instrument_handlers_base(module):
     module.BaseHandler.get_response = get_response_wrapper(
         module.BaseHandler.get_response)
 
+    def wrapper_async(fn):
+        @trace_handler_async(fn)
+        async def trace(*args, **kwargs):
+            ## asgi applicaiton 에서 threading.local()을 사용할 경우 데이터가 침해 될 수 있다.
+            ## contextvars 를 이용하여 현재 실행중인 코루틴 콘텍스트를 유지한다.
+            request = args[1]
+            scope = request.scope
+            ctx = scope.get(WHATAP_CTX)
+            callback = await fn(*args, **kwargs)
+            ctx.asgi_response = callback
+            if ctx and conf.trace_user_enabled:
+                if not conf.trace_user_using_ip:
+                    userid_util.setUserId(request, callback, ctx._rawuserid)
+
+            return callback
+        return trace
+    if hasattr(module, 'BaseHandler') and hasattr(module.BaseHandler, 'get_response_async'):
+        module.BaseHandler.get_response_async = wrapper_async(module.BaseHandler.get_response_async)
     # if django_py3_loaded:
     #     instrument_handlers_async(module)
 
