@@ -380,11 +380,10 @@ def interceptor_db_con(fn, db_type, *args, **kwargs):
     if not kwargs:
         kwargs = dict(
             x.split('=') for x in re.sub(r'\s*=\s*', '=', args[0]).split())
-    ctx = TraceContextManager.getLocalContext()
     text = '{}://'.format(db_type)
     text += kwargs.get('user')
     text += "@"
-    text += kwargs.get('host')
+    text += kwargs.get('host',kwargs.get('dsn','') )
     text += '/'
     text += kwargs.get('database', kwargs.get('db', kwargs.get('dbname', '')))
     ctx.active_dbc = text
@@ -456,7 +455,6 @@ def interceptor_db_execute(fn, *args, **kwargs):
     except Exception as e:
         interceptor_step_error(e)
     finally:
-        ctx = TraceContextManager.getLocalContext()
         datas = [ctx.lctx.get('dbc', ''), query]
         ctx.elapsed = DateUtil.nowSystem() - start_time
         async_sender.send_packet(PacketTypeEnum.TX_SQL, ctx,
