@@ -17,7 +17,6 @@ DEFINITION = {
     ],
     'httpc_urllib3': [
         ('urllib3.request', 'instrument_urllib3'),
-        # ('requests.packages.urllib3.request', 'instrument_urllib3'),
     ],
     'httpc_django': [
         ('revproxy.views', 'instrument_revproxy_views'),
@@ -50,8 +49,6 @@ DEFINITION = {
     ],
     'application_django': [
         ('django.core.handlers.wsgi', 'instrument'),
-        ('django.core.handlers.asgi', 'instrument_asgi'),
-        
         ('django.core.handlers.base', 'instrument_handlers_base'),
         ('django.views.generic.base', 'instrument_generic_base'),
         ('django.contrib.staticfiles.handlers', 'instrument_handlers_static'),
@@ -64,6 +61,9 @@ DEFINITION = {
          False),
 
     ],
+    'application_django_asgi': [
+        ('django.core.handlers.asgi', 'instrument_asgi'),
+    ],
     'application_flask': [
         ('flask', 'instrument'),
     ],
@@ -71,15 +71,9 @@ DEFINITION = {
         ('tornado.web', 'instrument'),
     ],
     'application_celery': [
-        # ('celery.task.base', 'instrument_task_base'),
-        #('celery.app.task', 'instrument_app_task'),
-        #('celery.worker', 'instrument_celery_worker'),
-        #('celery.concurrency.processes', 'instrument_celery_worker'),
-        #('celery.concurrency.prefork', 'instrument_celery_worker'),
         ('celery.execute.trace', 'instrument_celery_execute_trace'),
         ('celery.task.trace', 'instrument_celery_execute_trace'),
         ('celery.app.trace', 'instrument_celery_execute_trace'),
-        #('billiard.pool', 'instrument_billiard_pool'),
     ],
     'database_redis':[
         ('redis','instrument_redis_connection'),
@@ -87,9 +81,6 @@ DEFINITION = {
     'email_smtp':[
         ('smtplib','instrument_smtp'),
     ],
-    # 'amqp_kombu':[
-    #     ('kombu','instrument_kombu'),
-    # ],
     'amqp_pika':[
         ('pika.channel','instrument_pika'),
     ],
@@ -98,7 +89,10 @@ DEFINITION = {
         ('spsengine.containers', 'instrument_nameko_spawn_worker'),
     ],
     'application_graphql':[
-        #('graphql','instrument_graphql'),
+        #graphen-core 3.x~
+        ('graphql.execution.execute','instrument_graphql'),
+
+        #graphen-core 2.x
         ('graphql.execution.executor','instrument_graphql'),
     ],
     'database_mongo':[
@@ -117,4 +111,7 @@ DEFINITION = {
     'application_frappe': [
         ('frappe.app', 'instrument'),
     ],
+    'database_cxoracle':[
+        ('cx_Oracle', 'instrument_oracle_client'),
+    ],
 }
